pub struct SortedSetGetRankRequest {
pub set_name: Vec<u8>,
pub value: Vec<u8>,
pub order: i32,
}Fields
set_name: Vec<u8>value: Vec<u8>order: i32The order in which sorted set will be sorted to determine the rank.
When Order.ASCENDING is specified, will return the rank of the value when sorted set scores are ordered from low to high. This is the default when no Order is specified.
When Order.DESCENDING is specified, will return the rank of the value when sorted set scores are ordered from high to low.
Implementations