pub struct SortedSetUnionStoreRequest {
pub set_name: Vec<u8>,
pub sources: Vec<Source>,
pub aggregate: i32,
pub ttl_milliseconds: u64,
}Fields
set_name: Vec<u8>The destination set where the result of the union is stored.
sources: Vec<Source>The sets to compute the union for. Note that the destination set is not implicitly included as a source. It must be explicitly specified in sources if its current contents need to be included in the union.
aggregate: i32Aggregate function to determine the final score for an element that exists in multiple source sets
ttl_milliseconds: u64The TTL for the destination set if the result is non-empty
Implementations
Sourceimpl SortedSetUnionStoreRequest
impl SortedSetUnionStoreRequest
Sourcepub fn aggregate(&self) -> AggregateFunction
pub fn aggregate(&self) -> AggregateFunction
Returns the enum value of aggregate, or the default if the field is set to an invalid enum value.
Sourcepub fn set_aggregate(&mut self, value: AggregateFunction)
pub fn set_aggregate(&mut self, value: AggregateFunction)
Sets aggregate to the provided enum value.