pub struct SortedSetUnionStoreResponse {
pub length: u32,
}Fields
length: u32The number of elements in the destination set after the union. The length is 0 if the result of the union was an empty set.