pub enum WasmLocation {
Inline(Vec<u8>),
WasmId(WasmId),
}Variants
Inline(Vec<u8>)
The wasm for the Function is here, in the message. Will be uploaded as a separate Wasm
WasmId(WasmId)
The wasm for the Function is this id
Implementations
Sourceimpl WasmLocation
impl WasmLocation
Sourcepub fn merge(
field: &mut Option<WasmLocation>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<WasmLocation>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.