pub struct Function {
pub function_id: String,
pub name: String,
pub description: String,
pub current_version: Option<CurrentFunctionVersion>,
pub latest_version: u32,
pub concurrency_limit: u32,
pub last_updated_at: String,
}Expand description
A Function is an extension of Momento; for users to build their own Momento apis.
Fields
function_id: StringThis is an immutable unique identifier for the function, across versions.
name: StringThe name of the function.
description: StringA convenience for consoles.
current_version: Option<CurrentFunctionVersion>What is the current version of the function set to use upon invocation?
latest_version: u32What is the actual latest version of the function?
concurrency_limit: u32How many concurrent invocations are allowed for this function
last_updated_at: StringHuman-readable datetime string in UTC format