pub struct FunctionVersion {
pub id: Option<FunctionId>,
pub wasm_id: Option<WasmId>,
pub environment: HashMap<String, EnvironmentValue>,
}Expand description
A specific version of a Function, with its versioned configuration data.
Fields
id: Option<FunctionId>This unique identifier should change when a function’s metadata is updated
wasm_id: Option<WasmId>The wasm ID this function uses
environment: HashMap<String, EnvironmentValue>The environment variables available to this function via the WASI environment interface