pub struct Wasm {
pub id: Option<WasmId>,
pub name: String,
pub description: String,
}Expand description
Metadata for a wasm archive. These can exist independently of a Function. For example, Templates are just special Wasm archives that are accessible to more than 1 user. In this way, we can manage Templates independently of concrete user Functions, and users can reuse their wasms across multiple Functions (which would be different configurations).
Fields
id: Option<WasmId>The globally unique identifier tuple for this wasm. It may be a shared ID, as in the case of a Template Function, or it may be unique to one Function.
name: StringThe name of the wasm.
description: StringThe description of the wasm.