pub struct WasmId {
pub id: String,
pub version: u32,
}Fields
id: StringGlobally unique id, this is stable across versions of the wasm.
version: u32A sub-id of sorts. Together with the id, this is a unique identifier for a wasm binary.