pub struct CacheCommand {
pub message_id: u64,
pub control_code: u32,
pub rpc_kind: Option<RpcKind>,
}Expand description
All messages sent to the server by a client must be CacheCommands.
Fields
message_id: u64This is the unique identifier used for the command. The server will return this id in the response. As protosocket-rpc does not necessarily respond in-order this is used to correlate responses with requests.
control_code: u32The protosocket-rpc control code.
rpc_kind: Option<RpcKind>The protosocket-rpc rpc kind.