pub struct CacheResponse {
pub message_id: u64,
pub control_code: u32,
pub kind: Option<Kind>,
}Expand description
All messages sent by the server to a client will be CacheResponses.
Fields
message_id: u64This is the message id provided in the corresponding command.
control_code: u32The protosocket-rpc control code.
kind: Option<Kind>The specific response.